#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import xml.etree.ElementTree as ET
import json
import datetime

url = 'https://download.microsoft.com/download/0/1/8/018E208D-54F8-44CD-AA26-CD7BC9524A8C/PublicIPs_20171226.xml'
r = requests.get(url)
office365 = ET.fromstring(r.text)
l = []
for region in office365.iter('Region'):
    for subnet in region.iter('IpRange'):
        l.append(subnet.get('Subnet'))

warninglist = {}
warninglist['name'] = 'List of known Microsoft Azure Datacenter IP Ranges'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'Microsoft Azure Datacenter IP Ranges'
warninglist['list'] = sorted(set(l))
warninglist['matching_attributes'] = ["ip-src", "ip-dst", "domain|ip"]
warninglist['type'] = 'cidr'

print(json.dumps(warninglist))



#!/usr/bin/env python3
# Tool to check for openresolvers (from list of source IP).
#
# Dragon Research Group project
#
# Software is free software released under the "Modified BSD license"
#
# Copyright (c) 2015 Alexandre Dulaunoy - a@foo.be
#
# Has been modified by Edvard Rejthar, CSIRT.cz at MISP Hackathon 7 Dec 2016
#
#
import os, sys, argparse, redis, datetime, ipdb, json, threading, jsonpickle
from dns.resolver import Resolver, NXDOMAIN, NoNameservers, Timeout
from urllib.request import urlopen
from netaddr import IPAddress, AddrFormatError
import logging
logging.basicConfig(level=logging.DEBUG, format='%(message)s')
logger = logging.getLogger('openresolverchecker')
__help__ = """
Check the list of IP/domains agains an IP to see where is open resolvers.

Examples:
./openresolverchecker.py 
./openresolverchecker.py --max 2000 --out save.json --include-timeouts
./openresolverchecker.py -v -o save.json --type TXT --query resolvertest.switch.ch "resolver test ok" 
./openresolverchecker.py -v -o save.json --type A --query seznam.cz 77.75.77.53 --input ../list.json --max 100

"""

DEFAULT_QUERY, DEFAULT_IP = "resolvertest.switch.ch", "resolver test ok"
MISP_WARNING_LIST = "https://raw.githubusercontent.com/MISP/misp-warninglists/master/lists/public-dns-v4/list.json"

class OpenResolverChecker:
    def __init__(self, ips, query = DEFAULT_QUERY, expected = DEFAULT_IP, threadnum = 500, verbose = 0, recordType = "TXT", includeTimeouts = False ):
        self.resolver = Resolver()
        self.resolver.timeout=1
        self.resolver.lifetime=1
        self.query = query
        self.expected = expected
        self.openresolvers = [] # [address, ...]
        self.errors = [] # [(address, errcode), ...]
        self.ips = ips                    
        self.threadnum = threadnum                
        self.verbose = verbose
        self.recordType = recordType
        self.includeTimeouts = includeTimeouts

    def _worker(cls,num, this):
        """ Worker thread checks if the IP is an Open resolver. """
        while True:                                  
            try:
                ip = this.ips.pop()
            except IndexError:
                return False
            
            ts = str(datetime.datetime.utcnow())
            
            try:
                IPAddress(ip) # check
                addresses = [ip]
            except AddrFormatError:  
                addresses = []
                try:
                    answer = dns.resolver.query(ip, 'AAAA')
                    for data in answer: 
                        addresses.append(data)
                    answer = dns.resolver.query(ip, 'A')
                    for data in answer: 
                        addresses.append(data)
                except:
                    #logging.warning("Cant translate to the IP: {}".format(ip))
                    this.errors.append((ip, "untranslatable"))
                    if this.verbose > 0:
                        print("Left:{} (Worker {}) {} {}".format(len(this.ips), num, "untranslatable", ip))
                    continue
            
            for ip in addresses:
                passed, msg = this.check(address=ip)                
                #if passed:
                    #this.openresolvers.append(ip)                
                    #logline = ts+" - Open resolver at "+ip+" "+str(tst)                
                #else:
                    #logline = "{} closed".format(ip)                
                if this.verbose > 0:
                    print("Left:{} (Worker {}) {} {}".format(len(this.ips), num, msg, ip))
            
    
    def launch(self):
        """ Launch analysis in threads. """
        threads = []        
        for i in range(self.threadnum):
            th = threading.Thread(target=self._worker, args=(i,self))
            threads.append(th)
            th.start()

        for x in threads:
            x.join()

        return self.openresolvers

    
    def check(self, address=None):
        """ False : not an openresolver
        True is an open resolver
        (True, ip) is an open resolver and includes the non expected A record """
        if address is None:
            return None                
                        
        self.resolver.nameservers=[address]
        try:            
            #print("QUERY",self.query, self.recordType)             
            answer = self.resolver.query(self.query, self.recordType)
            result = next(answer.__iter__()).to_text().strip('"')            
            if result == self.expected:
                self.openresolvers.append(address)
                return (True, "*** open resolver")
            else:
                self.errors.append((address, "Wrong answer: {}".format(txt)))
                return (False, "Wrong answer: {}".format(txt))
        except Timeout as e:            
            if not self.includeTimeouts:                
                return (False, "Timeout")
            else:
                ex = e
        except Exception as e:                        
            ex = e
            # NXDOMAIN = lies that the know domain does not exist                        
            # NoNameservers = Refused – they claim to be but are not. Ex ns1.eurodns.com", 80.92.65.2
            # any other reason
            pass        
        self.errors.append((address, ex.__class__.__name__))
        return (False, ex.__class__.__name__)
    
if __name__ == "__main__":    
    # command line args
    parser = argparse.ArgumentParser(description=__help__, formatter_class=argparse.RawTextHelpFormatter)
    parser.add_argument('-q','--query', help='<query> <expected ip> EX: {} {}'.format(DEFAULT_QUERY, DEFAULT_IP),nargs=2, default=(DEFAULT_QUERY, DEFAULT_IP))    
    parser.add_argument('-o','--out', help='output file to store the list of open resolvers')
    parser.add_argument('-v','--verbose', help='verbose output', action="count", default = 0)
    parser.add_argument('--type', help='Specify the type of record we\'re checking. Default is TXT record but you might want to use an A record.', default="TXT")
    parser.add_argument('--include-timeouts', help='Include timeout exception to error results. Normally, only Nxdomain and NoNameservers exceptions are treated as errors.', action="store_true")
    parser.add_argument('-m','--max', help='max open resolvers to check (IE. only first 100)', type=int)
    parser.add_argument('-t','--threadnum', help='thread number (default 500)', type=int, default=500)
    parser.add_argument('-i','--input', help="Source file in the format: {'list':[ip, domain...]}. If no file is given, MISP "+MISP_WARNING_LIST+" will be used instead.", default=None)            
    args = parser.parse_args()        
        
    # load resolvers list    
    if args.input:
        try: # local file
            with open(args.input) as f:
                sourceFile = json.load(f)
        except FileNotFoundError:
            sys.exit("File {} not found.".format(args.input))
    else: # load from github       
        print("Downloading the list from: {}".format(MISP_WARNING_LIST))
        response = urlopen(MISP_WARNING_LIST)
        sourceFile = json.loads(response.read().decode('utf-8'))
        
    
    ips = sourceFile["list"]                
    if args.max:
        ips = ips[:args.max]
    count = len(ips)
    if not count:
        print("Nothing to be checked, empty list.")
        quit()                          
    
    # launch resolvers
    orc = OpenResolverChecker(ips, args.query[0], args.query[1], threadnum = args.threadnum, verbose = args.verbose, recordType=args.type, includeTimeouts = args.include_timeouts)
    orc.launch()
        
    # work with results
    if args.out: # save to file
        with open(args.out, "w") as f:
            sourceFile.update({"timestamp": str(datetime.datetime.utcnow()), 
                               "openresolvers": orc.openresolvers,                                
                               "ip-checked": count, 
                               "open-ratio": (len(orc.openresolvers)/count),  
                               "query": args.query[0], 
                               "query-expected-ip": args.query[1],
                               "query-record-type": args.type,
                               "errors": orc.errors
                               })            
            json.dump(sourceFile, f, indent=4, sort_keys = True)            
    else: # print to stdout
        print("Valid resolvers:")
        print(orc.openresolvers)    
    print("Resolvers checked: {}, opens: {} ({} %), errors {} ({} %)".format(count,                                                                                 len(orc.openresolvers), (len(orc.openresolvers)/count)*100 ,len(orc.errors),(len(orc.errors)/count*100)))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import xml.etree.ElementTree as ET
import json
import datetime

url = 'https://download.microsoft.com/download/3/5/3/353F871C-5CF8-4CF8-8A76-6A88D9CA1ABE/PublicIPs_MC_20171211.xml'
r = requests.get(url)
office365 = ET.fromstring(r.text)
l = []
for region in office365.iter('Region'):
    for subnet in region.iter('IpRange'):
        l.append(subnet.get('Subnet'))

warninglist = {}
warninglist['name'] = 'List of known Office 365 IP address ranges in China'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'Office 365 IP address ranges in China'
warninglist['list'] = sorted(set(l))
warninglist['matching_attributes'] = ["ip-src", "ip-dst", "domain|ip"]
warninglist['type'] = 'cidr'

print(json.dumps(warninglist))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import zipfile
import datetime
import json

tranco_url = 'https://tranco-list.eu/top-1m.csv.zip'
tranco_file = 'top-1m.csv.zip'
user_agent = {'User-agent': 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:46.0) Gecko/20100101 Firefox/46.0'}
r = requests.get(tranco_url, headers=user_agent)
with open(tranco_file, 'wb') as fd:
    for chunk in r.iter_content(4096):
        fd.write(chunk)
with zipfile.ZipFile(tranco_file, 'r') as tranco_lists:
    for name in tranco_lists.namelist():
        if name == 'top-1m.csv':
            with tranco_lists.open(name) as tranco:
                sites = tranco.readlines()
        else:
            continue

tranco_warninglist = {}
version = int(datetime.date.today().strftime('%Y%m%d'))

tranco_warninglist['description'] = "Event contains one or more entries from the top 1,000,000 most-used sites (Tranco)."
d = datetime.datetime.now()
tranco_warninglist['version'] = version
tranco_warninglist['name'] = "Top 1,000,000 most-used sites from Tranco"
tranco_warninglist['type'] = 'hostname'
tranco_warninglist['list'] = []
tranco_warninglist['matching_attributes'] = ['hostname', 'domain', 'url', 'domain|ip']

for site in sites:
    v = site.decode('UTF-8').split(',')[1]
    tranco_warninglist['list'].append(v.rstrip())
tranco_warninglist['list'] = sorted(set(tranco_warninglist['list']))
print(json.dumps(tranco_warninglist))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import datetime
import json
import csv
import os

# TODO: Include MozRank

moz_url_domains = "https://moz.com/top500/domains/csv"
moz_url_pages = "https://moz.com/top500/pages/csv"

moz_file_domains = "/tmp/top500.domains.csv"
moz_file_pages = "/tmp/top500.pages.csv"

user_agent = {"User-agent": "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:46.0) Gecko/20100101 Firefox/46.0"}

rDomains = requests.get(moz_url_domains, headers=user_agent)
rPages = requests.get(moz_url_pages, headers=user_agent)
open(moz_file_domains, 'wb').write(rDomains.content)
open(moz_file_pages, 'wb').write(rPages.content)

moz_warninglist = {}
version = int(datetime.date.today().strftime('%Y%m%d'))

moz_warninglist['description'] = "Event contains one or more entries from the top 500 of the most used domains (Mozilla)."
d = datetime.datetime.now()
moz_warninglist['version'] = version
moz_warninglist['name'] = "Top 500 domains and pages from https://moz.com/top500"
moz_warninglist['type'] = 'hostname'
moz_warninglist['list'] = []
moz_warninglist['matching_attributes'] = ['hostname', 'domain', 'uri', 'url']

with open(moz_file_domains) as csv_file:
    csv_reader = csv.reader(csv_file, delimiter=',')
    line_count = 0
    for row in csv_reader:
        if line_count == 0:
            #print(f'Column names are {", ".join(row)}')
            line_count += 1
        else:
            #print(f'\t{row[0]}. {row[1]}, MozTrust: {row[5]}.')
            v = row[1]
            moz_warninglist['list'].append(v.rstrip().rstrip('/'))
            line_count += 1

with open(moz_file_pages) as csv_file:
    csv_reader = csv.reader(csv_file, delimiter=',')
    line_count = 0
    for row in csv_reader:
        if line_count == 0:
            #print(f'Column names are {", ".join(row)}')
            line_count += 1
        else:
            #print(f'\t{row[0]}. {row[1]}, MozTrust: {row[5]}.')
            v = row[1]
            moz_warninglist['list'].append(v.rstrip().rstrip('/'))
            line_count += 1

moz_warninglist['list'] = sorted(set(moz_warninglist['list']))
print(json.dumps(moz_warninglist))

try:
    os.remove(moz_file_domains)
    os.remove(moz_file_pages)
except:
    print(f'Perhaps {moz_file_domains}/{moz_file_pages} does not exist.')



#!/usr/bin/env python3

import datetime
import logging
import json
import os
import requests

servers_url = 'http://downloads.majestic.com/majestic_million.csv'
csv_path = 'majestic_million.csv'
hostname_path = 'list.json'

if os.path.isfile(csv_path):
    logging.warning('Not erasing local csv file')
else:
    req = requests.get(servers_url)
    with open(csv_path, 'wb') as fd:
        for chunk in req.iter_content(4096):
            fd.write(chunk)

host_list = []
with open(csv_path, newline='\n', encoding='utf-8', errors='replace') as csv_file:
    top10k = csv_file.readlines()[:10000]

version = int(datetime.date.today().strftime('%Y%m%d'))
out_list = {}

out_list['name'] = 'Top 10K websites from Majestic Million'
out_list['version'] = version
out_list['description'] = 'Event contains one or more entries from the top 10K of the most used websites (Majestic Million).'
out_list['matching_attributes'] = ['hostname', 'domain']
out_list['type'] = 'hostname'
out_list['list'] = sorted(set(host_list))

for hostname in top10k:
    v = hostname.split(',')[2]
    out_list['list'].append(v.rstrip())
out_list['list'] = sorted(set(out_list['list']))
with open(hostname_path, 'w', newline='\n') as hostname_file:
    hostname_file.write(json.dumps(out_list, indent=2, sort_keys=False))



#!/usr/bin/env python3

import csv
import datetime
import io
import json
import requests

from OpenSSL.crypto import load_certificate, FILETYPE_PEM

Included_CA_url = 'https://ccadb-public.secure.force.com/mozilla/IncludedCACertificateReportPEMCSV'
Included_CA_file = 'IncludedCACertificateReportPEMCSV.csv'
Included_CA_dst = 'mozilla-CA'
CA_known_intermediate_url = 'https://ccadb-public.secure.force.com/mozilla/PublicAllIntermediateCertsWithPEMCSV'
CA_known_intermediate_file = 'PublicAllIntermediateCertsWithPEMCSV.csv'
CA_known_intermediate_dst = 'mozilla-IntermediateCA'

def download(url, file):
    r = requests.get(url)
    with open(file, 'wb') as fd:
        for chunk in r.iter_content(4096):
            fd.write(chunk)

def gethash(cert, digest):
    return cert.digest(digest).decode('ASCII').replace(':', '').lower()

def process(file, dst, type):
    hashes = set()
    with open(file, 'r') as f_in:
        for obj in csv.DictReader(f_in):
            pem = obj['PEM Info'].strip("'").replace('\r','').replace('\n\n','\n')
            try:
                name = obj['Certificate Name']
            except:
                name = obj['Common Name or Certificate Name']
            cert = load_certificate(FILETYPE_PEM, pem)
            hashes.add(gethash(cert, 'md5'))
            hashes.add(gethash(cert, 'sha1'))
            hashes.add(obj['SHA-256 Fingerprint'].lower())
    warninglist = {}
    warninglist['name'] = 'Fingerprint of {type}'.format(type=type)
    warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
    warninglist['description'] = "Fingerprint of {type} taken from Mozilla's lists at https://wiki.mozilla.org/CA".format(type=type)
    warninglist['list'] = sorted(hashes)
    warninglist['type'] = 'string'
    warninglist['matching_attributes'] = ["md5", "sha1", "sha256", "filename|md5", "filename|sha1", "filename|sha256", "x509-fingerprint-md5", "x509-fingerprint-sha1", "x509-fingerprint-sha256"]
    with open('../lists/{dst}/list.json'.format(dst=dst), 'w') as data_file:
        json.dump(warninglist, data_file, indent=2, sort_keys=True)
        data_file.write("\n")

if __name__ == '__main__':
    download(Included_CA_url, Included_CA_file)
    process(Included_CA_file, Included_CA_dst, 'trusted CA certificates')
    download(CA_known_intermediate_url, CA_known_intermediate_file)
    process(CA_known_intermediate_file, CA_known_intermediate_dst, 'known intermedicate of trusted certificates')



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import json
from json import JSONEncoder
import sys
import collections
from glob import glob
from ipaddress import ip_address, ip_network
from pathlib import Path


try:
    import jsonschema
    HAS_JSONSCHEMA = True
except ImportError:
    HAS_JSONSCHEMA = False


class EncodeWarningList(JSONEncoder):
    def default(self, obj):
        if isinstance(obj, WarningList):
            return obj.to_dict()
        return JSONEncoder.default(self, obj)


class PyMISPWarningListsError(Exception):
    def __init__(self, message):
        super(PyMISPWarningListsError, self).__init__(message)
        self.message = message


class WarningList():

    expected_types = ['string', 'substring', 'hostname', 'cidr', 'regex']

    def __init__(self, warninglist, slow_search=False):
        self.warninglist = warninglist
        self.list = self.warninglist['list']
        self.description = self.warninglist['description']
        self.version = int(self.warninglist['version'])
        self.name = self.warninglist['name']
        if self.warninglist['type'] not in self.expected_types:
            raise PyMISPWarningListsError(f'Unexpected type ({self.warninglist["type"]}), please update the expected_type list')
        self.type = self.warninglist['type']
        if self.warninglist.get('matching_attributes'):
            self.matching_attributes = self.warninglist['matching_attributes']

        self.slow_search = slow_search
        self._network_objects = []

        if self.slow_search and self.type == 'cidr':
            self._network_objects = self._network_index()
            # If network objects is empty, reverting to default anyway
            if not self._network_objects:
                self.slow_search = False

    def __repr__(self):
        return f'<{self.__class__.__name__}(type="{self.name}", version="{self.version}", description="{self.description}")'

    def __contains__(self, value):
        if self.slow_search:
            return self._slow_search(value)
        return self._fast_search(value)

    def to_dict(self):
        to_return = {'list': [str(e) for e in self.list], 'name': self.name,
                     'description': self.description, 'version': self.version,
                     'type': self.type}
        if hasattr(self, 'matching_attributes'):
            to_return['matching_attributes'] = self.matching_attributes
        return to_return

    def to_json(self):
        return json.dumps(self, cls=EncodeWarningList)

    def _fast_search(self, value):
        return value in self.list

    def _network_index(self):
        to_return = []
        for entry in self.list:
            try:
                # Try if the entry is a network bloc or an IP
                to_return.append(ip_network(entry))
            except ValueError:
                pass
        return to_return

    def _slow_search(self, value):
        if self.type == 'string':
            # Exact match only, using fast search
            return self._fast_search(value)
        elif self.type == 'substring':
            # Expected to match on a part of the value
            # i.e.: value = 'blah.de' self.list == ['.fr', '.de']
            return any(v in value for v in self.list)
        elif self.type == 'hostname':
            # Expected to match on hostnames in URLs (i.e. the search query is a URL)
            # So we do a reverse search if any of the entries in the list are present in the URL
            # i.e.: value = 'http://foo.blah.de/meh' self.list == ['blah.de', 'blah.fr']
            return any(v in value for v in self.list)
        elif self.type == 'cidr':
            try:
                value = ip_address(value)
            except ValueError:
                # The value to search isn't an IP address, falling back to default
                return self._fast_search(value)
            return any((value == obj or value in obj) for obj in self._network_objects)


class WarningLists(collections.Mapping):

    def __init__(self, slow_search=False, lists=False):
        """Load all the warning lists from the package.
        :slow_search: If true, uses the most appropriate search method. Can be slower. Default: exact match.
        :lists: A list of warning lists (typically fetched from a MISP instance)
        """
        if not lists:
            lists = []
            self.root_dir_warninglists = Path(sys.modules['pymispwarninglists'].__file__).parent / 'data' / 'misp-warninglists' / 'lists'
            for warninglist_file in glob(str(self.root_dir_warninglists / '*' / 'list.json')):
                with open(warninglist_file, 'r') as f:
                    lists.append(json.load(f))
        if not lists:
            raise PyMISPWarningListsError('Unable to load the lists. Do not forget to initialize the submodule (git submodule update --init).')
        self.warninglists = {}
        for warninglist in lists:
            self.warninglists[warninglist['name']] = WarningList(warninglist, slow_search)

    def validate_with_schema(self):
        if not HAS_JSONSCHEMA:
            raise ImportError('jsonschema is required: pip install jsonschema')
        schema = Path(sys.modules['pymispwarninglists'].__file__).parent / 'data' / 'misp-warninglists' / 'schema.json'
        with open(schema, 'r') as f:
            loaded_schema = json.load(f)
        for w in self.warninglists.values():
            jsonschema.validate(w.warninglist, loaded_schema)

    def __getitem__(self, name):
        return self.warninglists[name]

    def __iter__(self):
        return iter(self.warninglists)

    def search(self, value):
        matches = []
        for name, wl in self.warninglists.items():
            if value in wl:
                matches.append(wl)
        return matches

    def __len__(self):
        return len(self.warninglists)

    def get_loaded_lists(self):
        return self.warninglists



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import json
import datetime
import urllib.request
import re
import ipaddress 

res = urllib.request.urlopen('http://noc.wikimedia.org/conf/reverse-proxy.php.txt')

res_body = res.read()
decoded = res_body.decode("unicode_escape", "utf-8")

l = []
for line in decoded.split('\n'):
    if re.search("public", line):
        matched = re.findall(r'\'(.*?)\'', line)
        if matched:
            try:
                ipaddress.ip_network(matched[0])
                l.append(matched[0])
            except ValueError:
                pass
   
warninglist = {}
warninglist['name'] = 'List of known Wikimedia address ranges'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'Wikimedia address ranges (http://noc.wikimedia.org/conf/reverse-proxy.php.txt)'
warninglist['type'] = 'cidr'
warninglist['list'] = sorted(set(l))
warninglist['matching_attributes'] = ["ip-src", "ip-dst", "domain|ip"]

print(json.dumps(warninglist))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import json
import datetime

url = 'https://raw.githubusercontent.com/ejrv/VPNs/master/vpn-ipv4.txt'
r = requests.get(url, stream=True)
ipsv4 = []
for ip in r.iter_lines():
    v = ip.decode('utf-8')
    if not v.startswith("#"):
        if v: ipsv4.append(v)

warninglist = {}
warninglist['name'] = 'Specialized list of IPv4 addresses belonging to common VPN providers and datacenters'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'Specialized list of IPv4 addresses belonging to common VPN providers and datacenters'
warninglist['list'] = sorted(set(ipsv4))
warninglist['type'] = 'cidr'
warninglist['matching_attributes'] = ["ip-src", "ip-dst", "domain|ip"]


with open('../lists/vpn-ipv4/list.json', 'w') as data_file:
    json.dump(warninglist, data_file, indent=4, sort_keys=True)


url = 'https://raw.githubusercontent.com/ejrv/VPNs/master/vpn-ipv6.txt'
r = requests.get(url, stream=True)
ipsv6 = []
for ip in r.iter_lines():
    v = ip.decode('utf-8')
    if not v.startswith("#"):
        if v: ipsv6.append(v)

warninglist = {}
warninglist['name'] = 'Specialized list of IPv6 addresses belonging to common VPN providers and datacenters'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'Specialized list of IPv6 addresses belonging to common VPN providers and datacenters'
warninglist['list'] = sorted(set(ipsv6))
warninglist['type'] = 'cidr'
warninglist['matching_attributes'] = ["ip-src", "ip-dst", "domain|ip"]


with open('../lists/vpn-ipv6/list.json', 'w') as data_file:
    json.dump(warninglist, data_file, indent=4, sort_keys=True)





#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import json
import datetime

url = 'https://raw.githubusercontent.com/martenson/disposable-email-domains/master/disposable_email_blocklist.conf'
r = requests.get(url, stream=True)
domain = []
for ip in r.iter_lines():
    v = ip.decode('utf-8')
    if not v.startswith("#"):
        if v: domain.append(v)

warninglist = {}
warninglist['name'] = 'List of disposable email domains'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'List of disposable email domains'
warninglist['list'] = sorted(set(domain))
warninglist['type'] = 'substring'
warninglist['matching_attributes'] = ["email-src", "email-dst", "whois-registrant-email", "domain|ip", "dns-soa-email"]

with open('../lists/disposable-email/list.json', 'w') as data_file:
    json.dump(warninglist, data_file, indent=4, sort_keys=True)





#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import json
import datetime
import urllib.request
import json

res = urllib.request.urlopen('https://ip-ranges.amazonaws.com/ip-ranges.json')

res_body = res.read()
j = json.loads(res_body.decode("utf-8"))
l = []

for prefix in j['prefixes']:
   l.append(prefix['ip_prefix'])

for prefix in j['ipv6_prefixes']:
   l.append(prefix['ipv6_prefix'])
   
warninglist = {}
warninglist['name'] = 'List of known Amazon AWS IP address ranges'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'Amazon AWS IP address ranges (https://ip-ranges.amazonaws.com/ip-ranges.json)'
warninglist['type'] = 'cidr'
warninglist['list'] = sorted(set(l))
warninglist['matching_attributes'] = ["ip-src", "ip-dst", "domain|ip"]

print(json.dumps(warninglist))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import zipfile
import datetime
import json

alexa_url = "http://s3.amazonaws.com/alexa-static/top-1m.csv.zip"
alexa_file = "top-1m.csv.zip"
user_agent = {"User-agent": "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:46.0) Gecko/20100101 Firefox/46.0"}
r = requests.get(alexa_url, headers=user_agent)
with open(alexa_file, 'wb') as fd:
    for chunk in r.iter_content(4096):
        fd.write(chunk)
with zipfile.ZipFile(alexa_file, 'r') as alexa_lists:
    for name in alexa_lists.namelist():
        if name == "top-1m.csv":
            with alexa_lists.open(name) as top:
                top1000 = top.readlines()[:1000]
        else:
            continue

alexa_warninglist = {}
version = int(datetime.date.today().strftime('%Y%m%d'))

alexa_warninglist['description'] = "Event contains one or more entries from the top 1000 of the most used website (Alexa)."
d = datetime.datetime.now()
alexa_warninglist['version'] = version
alexa_warninglist['name'] = "Top 1000 website from Alexa"
alexa_warninglist['type'] = 'hostname'
alexa_warninglist['list'] = []
alexa_warninglist['matching_attributes'] = ['hostname', 'domain']

for site in top1000:
    v = site.decode('UTF-8').split(',')[1]
    alexa_warninglist['list'].append(v.rstrip())
alexa_warninglist['list'] = sorted(set(alexa_warninglist['list']))
print(json.dumps(alexa_warninglist))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import json
import datetime

url = 'https://endpoints.office.com/endpoints/worldwide?clientrequestid=b10c5ed1-bad1-445f-b386-b919946339a7'
r = requests.get(url)
service_list = r.json()
lurls= []
lips = []

for service in service_list:
    for url in service.get('urls', []):
        lurls.append(url.replace('*', ''))
    for ip in service.get('ips', []):
        lips.append(ip)

warninglist = {}
warninglist['name'] = 'List of known Office 365 URLs address ranges'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'Office 365 URLs and IP address ranges'
warninglist['type'] = 'string'
warninglist['list'] = sorted(set(lurls))
warninglist['matching_attributes'] = ["domain", "domain|ip", "hostname"]


with open('../lists/microsoft-office365/list.json', 'w') as data_file:
    json.dump(warninglist, data_file, indent=4, sort_keys=True)

warninglist = {}
warninglist['name'] = 'List of known Office 365 IP address ranges'
warninglist['version'] = int(datetime.date.today().strftime('%Y%m%d'))
warninglist['description'] = 'Office 365 URLs and IP address ranges'
warninglist['list'] = sorted(set(lips))
warninglist['type'] = 'cidr'
warninglist['matching_attributes'] = ["ip-src", "ip-dst", "domain|ip"]


with open('../lists/microsoft-office365-ip/list.json', 'w') as data_file:
    json.dump(warninglist, data_file, indent=4, sort_keys=True)



#!/usr/bin/env python3

import json
import os
import requests
import datetime
import io

base_url="https://www.cloudflare.com/"
uri_list=['ips-v4','ips-v6']
dict=dict()
dict['list']=list()
def source_read_and_add(input_file):
	output_list=list()

	for line in input_file.splitlines():
		output_list.append(line)
	return output_list


for uri in uri_list:
	url = base_url + uri
	r=requests.get(url)
	dict['list'] += source_read_and_add(r.text)

dict['type'] = "cidr"
dict['matching_attributes']=["ip-dst","ip-src","domain|ip"]
dict['name']="List of known Cloudflare IP ranges"
dict['version']= int(datetime.date.today().strftime('%Y%m%d'))
dict['description']="List of known Cloudflare IP ranges (https://www.cloudflare.com/ips/)"
dict['list']=list(set(dict['list']))

print(json.dumps(dict))



#!/usr/bin/env python3


import requests
import datetime
import json

json_output=dict()
json_output['type']="hostname"
json_output['name']="University domains"
json_output['matching_attributes']=['hostname','domain','url','domain|ip']
json_output['version']= int(datetime.date.today().strftime('%Y%m%d'))
json_output['description']="List of University domains from https://raw.githubusercontent.com/Hipo/university-domains-list/master/world_universities_and_domains.json"
json_output['list']=list()



url="https://raw.githubusercontent.com/Hipo/university-domains-list/master/world_universities_and_domains.json"
university_list_file=requests.get(url)
university_list_json=university_list_file.json()

for university in university_list_json:
	for domain in university.get('domains'):
		if domain not in json_output['list']:
			json_output['list'].append(domain)

print(json.dumps(json_output))



#!/usr/bin/env python3

import json
import os
import requests
import datetime

base_url="https://raw.githubusercontent.com/threatstop/crl-ocsp-whitelist/master/"
uri_list=['crl-hostnames.txt','crl-ipv4.txt','crl-ipv6.txt','ocsp-hostnames.txt','ocsp-ipv4.txt','ocsp-ipv6.txt']
dict=dict()
dict['list']=list()
def source_read_and_add(input_file):
	output_list=list()
	for item in input_file:
		item=item.rstrip()
		output_list.append(item)
	return output_list


for uri in uri_list:
	url = base_url + uri
	r=requests.get(url)
	dict['list'] += source_read_and_add(r.text)

dict['type'] = "string"
dict['matching_attributes']=["hostname","domain","ip-dst","ip-src","url", "domain|ip"]
dict['name']="CRL Warninglist"
dict['version']= int(datetime.date.today().strftime('%Y%m%d'))
dict['description']="CRL Warninglist from threatstop (https://github.com/threatstop/crl-ocsp-whitelist/)"
dict['list']=list(set(dict['list']))

print(json.dumps(dict))



#!/usr/bin/env python3

import csv
import datetime
import logging
import ipaddress
import json
import os
import requests

servers_url = 'http://public-dns.info/nameservers.csv'
csv_path = 'nameservers.csv'
dns4_path = 'list4.json'
dns6_path = 'list6.json'

if os.path.isfile(csv_path):
    logging.warning('Not erasing local csv file')
else:
    req = requests.get(servers_url)
    with open(csv_path, 'wb') as fd:
        for chunk in req.iter_content(4096):
            fd.write(chunk)

ip4_list = []
ip6_list = []
with open(csv_path) as csv_file:
    servers_list = csv.reader(csv_file, delimiter=',', quotechar='"')

    for row in servers_list:
        if row[5] == '':
            try:
                ip = ipaddress.ip_address(row[0])

                if ip.version == 4:
                    list = ip4_list
                else:
                    list = ip6_list

                list.append(ip.compressed)
                if len(row[1]) > 0 and row[1] != '.':
                    list.append(row[1])

            except ValueError as exc:
                logging.warning(str(exc))

version = int(datetime.date.today().strftime('%Y%m%d'))

out4_list = {}
out4_list['name'] = 'List of known IPv4 public DNS resolvers'
out4_list['version'] = version
out4_list['description'] = 'Event contains one or more public IPv4 DNS resolvers as attribute with an IDS flag set'
out4_list['matching_attributes'] = ['ip-src', 'ip-dst', 'domain|ip']
out4_list['list'] = sorted(set(ip4_list))


out6_list = {}
out6_list['name'] = 'List of known IPv6 public DNS resolvers'
out6_list['version'] = version
out6_list['description'] = 'Event contains one or more public IPv6 DNS resolvers as attribute with an IDS flag set'
out6_list['matching_attributes'] = ['ip-src', 'ip-dst', 'domain|ip']
out6_list['list'] = sorted(set(ip6_list))


# print(json.dumps(out4_list, indent=True))
with open(dns4_path, 'w') as dns4_file:
    dns4_file.write(json.dumps(out4_list, indent=4, sort_keys=True))

with open(dns6_path, 'w') as dns6_file:
    dns6_file.write(json.dumps(out6_list, indent=4, sort_keys=True))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import json
import datetime

url = 'https://raw.githubusercontent.com/krassi/covid19-related/master/whitelist-domains.txt'
r = requests.get(url)
whitelist = r.text
whitelist = list(set(whitelist.split()))

warninglist = {
    'name': 'Covid-19 Krassi\'s Whitelist',
    'description': 'Krassimir\'s Covid-19 whitelist of known good Covid-19 related websites.',
    'type': 'hostname',
    'matching_attributes': ['domain', 'hostname', 'url'],
    'version': int(datetime.date.today().strftime('%Y%m%d')),
    'list': sorted(whitelist)
}

with open('../lists/covid-19-krassi-whitelist/list.json', 'w+') as data_file:
    json.dump(warninglist, data_file, indent=2, sort_keys=True)

url = 'https://raw.githubusercontent.com/Cyber-Threat-Coalition/goodlist/master/hostnames.txt'
r = requests.get(url)
whitelist = r.text
whitelist = list(set(whitelist.split()))

warninglist = {
    'name': 'Covid-19 Cyber Threat Coalition\'s Whitelist',
    'description': 'The Cyber Threat Coalition\'s whitelist of COVID-19 related websites.',
    'type': 'hostname',
    'matching_attributes': ['domain', 'hostname', 'url'],
    'version': int(datetime.date.today().strftime('%Y%m%d')),
    'list': sorted(whitelist)
}

with open('../lists/covid-19-cyber-threat-coalition-whitelist/list.json', 'w+') as data_file:
    json.dump(warninglist, data_file, indent=2, sort_keys=True)






#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#
#    A simple converter of MISP warning lists to asciidoctor format
#    Copyright (C) 2018 Alexandre Dulaunoy
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


import os
import json
import argparse

thisDir = os.path.dirname(__file__)

lists = []

pathLists = os.path.join(thisDir, '../lists')

for f in os.listdir(pathLists):
	filename = "{}/{}".format(f,"list.json")
	lists.append(filename)

lists.sort()

argParser = argparse.ArgumentParser(description='Generate documentation from MISP warning lists', epilog='Available warning lists are {0}'.format(lists))
argParser.add_argument('-v', action='store_true', help='Verbose mode')
args = argParser.parse_args()

def header(adoc=False):
    if adoc is False:
        return False

    dedication = "\n[dedication]\n== Funding and Support\nThe MISP project is financially and resource supported by https://www.circl.lu/[CIRCL Computer Incident Response Center Luxembourg ].\n\nimage:{images-misp}logo.png[CIRCL logo]\n\nA CEF (Connecting Europe Facility) funding under CEF-TC-2016-3 - Cyber Security has been granted from 1st September 2017 until 31th August 2019 as ***Improving MISP as building blocks for next-generation information sharing***.\n\nimage:{images-misp}en_cef.png[CEF funding]\n\nIf you are interested to co-fund projects around MISP, feel free to get in touch with us.\n\n"
    doc = adoc
    doc = doc + ":toc: right\n"
    doc = doc + ":toclevels: 1\n"
    doc = doc + ":toc-title: MISP warning lists\n"
    doc = doc + ":icons: font\n"
    doc = doc + ":sectanchors:\n"
    doc = doc + ":sectlinks:\n"
    doc = doc + ":images-cdn: https://raw.githubusercontent.com/MISP/MISP/2.4/INSTALL/logos/\n"
    doc = doc + ":images-misp: https://www.misp-project.org/assets/images/\n"
    doc = doc + "\n= MISP warning lists\n\n"
    doc = doc + "= Introduction\n"
    doc = doc + "\nimage::{images-cdn}misp-logo.png[MISP logo]\n\n"
    doc = doc + "The MISP threat sharing platform is a free and open source software helping information sharing of threat intelligence including cyber security indicators, financial fraud or counter-terrorism information. The MISP project includes multiple sub-projects to support the operational requirements of analysts and improve the overall quality of information shared.\n\n"
    doc = doc + ""
    doc = "{}{}".format(doc, "\nMISP warning lists are lists of well-known indicators that can be associated to potential false positives, errors or mistakes. The warning lists are integrated in MISP to display an info/warning box at the event and attribute level if such indicators are available in one of the list. The list can be globally enabled or disabled in MISP following the practices of the organization.\n")
    doc = doc + "The following document is generated from the machine-readable JSON describing the https://github.com/MISP/misp-warninglists[MISP warning lists]."
    doc = doc + "\n\n"
    doc = doc + "<<<\n"
    doc = doc + dedication
    doc = doc + "<<<\n"
    doc = doc + "= MISP warning lists\n"
    return doc

def asciidoc(content=False, adoc=None, t='title', title=''):
    adoc = adoc + "\n"
    output = ""
    if t == 'title':
        output = '== ' + content
    elif t == 'info':
        output = "\n{}.\n\n{} {} {} {}.".format(content, 'NOTE:' ,title, 'are warning lists available in JSON format at https://github.com/MISP/misp-warninglists/tree/master/lists.' ,'The JSON format can be freely reused in your application or automatically enabled in https://www.github.com/MISP/MISP[MISP]')
    elif t == 'description':
        output = "\n{} \n".format(content)
    elif t == 'list':
        output = "The warning list contains {} elements.\n".format(content)
    adoc = adoc + output
    return adoc
adoc = ""
print (header(adoc=adoc))

for warninglist in lists:
    fullPathLists = os.path.join(pathLists, warninglist)
    with open(fullPathLists) as fp:
        c = json.load(fp)
    title = c['name']
    adoc = asciidoc(content=title, adoc=adoc, t='title')
    adoc = asciidoc(content=c['description'], adoc=adoc, t='info', title=title)
    if 'matching_attributes' in c:
        adoc = asciidoc(content=c['matching_attributes'], adoc=adoc, t='matching_attributes')
    if 'list' in c:
        cards = len(c['list'])
    adoc = asciidoc(content=cards, adoc=adoc, t='list')

print(adoc)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pymispwarninglists', 'pymispwarninglists.data.misp-warninglists.tools']

package_data = \
{'': ['*'],
 'pymispwarninglists': ['data/misp-warninglists/*',
                        'data/misp-warninglists/lists/akamai/*',
                        'data/misp-warninglists/lists/alexa/*',
                        'data/misp-warninglists/lists/amazon-aws/*',
                        'data/misp-warninglists/lists/automated-malware-analysis/*',
                        'data/misp-warninglists/lists/bank-website/*',
                        'data/misp-warninglists/lists/cisco_top1000/*',
                        'data/misp-warninglists/lists/cloudflare/*',
                        'data/misp-warninglists/lists/common-contact-emails/*',
                        'data/misp-warninglists/lists/common-ioc-false-positive/*',
                        'data/misp-warninglists/lists/covid-19-cyber-threat-coalition-whitelist/*',
                        'data/misp-warninglists/lists/covid-19-krassi-whitelist/*',
                        'data/misp-warninglists/lists/covid/*',
                        'data/misp-warninglists/lists/crl-ip-hostname/*',
                        'data/misp-warninglists/lists/dax30/*',
                        'data/misp-warninglists/lists/disposable-email/*',
                        'data/misp-warninglists/lists/eicar.com/*',
                        'data/misp-warninglists/lists/empty-hashes/*',
                        'data/misp-warninglists/lists/google-gmail-sending-ips/*',
                        'data/misp-warninglists/lists/google/*',
                        'data/misp-warninglists/lists/googlebot/*',
                        'data/misp-warninglists/lists/ipv6-linklocal/*',
                        'data/misp-warninglists/lists/majestic_million/*',
                        'data/misp-warninglists/lists/microsoft-attack-simulator/*',
                        'data/misp-warninglists/lists/microsoft-azure/*',
                        'data/misp-warninglists/lists/microsoft-office365-cn/*',
                        'data/misp-warninglists/lists/microsoft-office365-ip/*',
                        'data/misp-warninglists/lists/microsoft-office365/*',
                        'data/misp-warninglists/lists/microsoft-win10-connection-endpoints/*',
                        'data/misp-warninglists/lists/microsoft/*',
                        'data/misp-warninglists/lists/moz-top500/*',
                        'data/misp-warninglists/lists/mozilla-CA/*',
                        'data/misp-warninglists/lists/mozilla-IntermediateCA/*',
                        'data/misp-warninglists/lists/multicast/*',
                        'data/misp-warninglists/lists/ovh-cluster/*',
                        'data/misp-warninglists/lists/public-dns-hostname/*',
                        'data/misp-warninglists/lists/public-dns-v4/*',
                        'data/misp-warninglists/lists/public-dns-v6/*',
                        'data/misp-warninglists/lists/rfc1918/*',
                        'data/misp-warninglists/lists/rfc3849/*',
                        'data/misp-warninglists/lists/rfc5735/*',
                        'data/misp-warninglists/lists/rfc6598/*',
                        'data/misp-warninglists/lists/rfc6761/*',
                        'data/misp-warninglists/lists/second-level-tlds/*',
                        'data/misp-warninglists/lists/security-provider-blogpost/*',
                        'data/misp-warninglists/lists/sinkholes/*',
                        'data/misp-warninglists/lists/tlds/*',
                        'data/misp-warninglists/lists/tranco/*',
                        'data/misp-warninglists/lists/university_domains/*',
                        'data/misp-warninglists/lists/url-shortener/*',
                        'data/misp-warninglists/lists/vpn-ipv4/*',
                        'data/misp-warninglists/lists/vpn-ipv6/*',
                        'data/misp-warninglists/lists/whats-my-ip/*',
                        'data/misp-warninglists/lists/wikimedia/*']}

install_requires = \
['coveralls>=2.0.0,<3.0.0']

setup_kwargs = {
    'name': 'pymispwarninglists',
    'version': '1.0',
    'description': 'Python API for the MISP warning lists.',
    'long_description': '# PyMISPWarningLists\n\n[![Build Status](https://travis-ci.org/MISP/PyMISPWarningLists.svg?branch=master)](https://travis-ci.org/MISP/PyMISPWarningLists)\n[![codecov.io](https://codecov.io/github/MISP/PyMISPWarningLists/coverage.svg?branch=master)](https://codecov.io/github/MISP/PyMISPWarningLists?branch=master)\n\nPythonic way to work with the warning lists defined there: https://github.com/MISP/misp-warninglists\n\n# Installation\n\n`pip install pymispwarninglists`\n\n# Usage\n\nWarning lists are represented as immutable Python dictionaries.\n\n',
    'author': 'Raphaël Vinot',
    'author_email': 'raphael.vinot@circl.lu',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from pathlib import Path
import json


for p in Path('../lists/').glob('*/*.json'):
    with p.open() as _f:
        warninglist = json.load(_f, encoding="utf-8")
    warninglist['list'] = sorted(list(set(warninglist['list'])))

    with p.open('w') as _f:
        warninglist = json.dump(warninglist, _f, indent=2, sort_keys=True, ensure_ascii=False)
        _f.write('\n')



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import requests
import zipfile
import datetime
import json

cisco_url = "http://s3-us-west-1.amazonaws.com/umbrella-static/top-1m.csv.zip"
cisco_file = "top-1m.csv.zip"
user_agent = {"User-agent": "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:46.0) Gecko/20100101 Firefox/46.0"}
r = requests.get(cisco_url, headers=user_agent)
with open(cisco_file, 'wb') as fd:
    for chunk in r.iter_content(4096):
        fd.write(chunk)
with zipfile.ZipFile(cisco_file, 'r') as cisco_lists:
    for name in cisco_lists.namelist():
        if name == "top-1m.csv":
            with cisco_lists.open(name) as top:
                top1000 = top.readlines()[:1000]
        else:
            continue

cisco_warninglist = {}
version = int(datetime.date.today().strftime('%Y%m%d'))

cisco_warninglist['description'] = 'Event contains one or more entries from the top 1000 of the most used website (Cisco Umbrella).'
d = datetime.datetime.now()
cisco_warninglist['version'] = version
cisco_warninglist['name'] = 'Top 1000 website from Cisco Umbrella'
cisco_warninglist['type'] = 'hostname'
cisco_warninglist['matching_attributes'] = ['hostname', 'domain']
cisco_warninglist['list'] = []


for site in top1000:
    v = str(site).split(',')[1]
    cisco_warninglist['list'].append(v.rstrip())
cisco_warninglist['list'] = sorted(set(cisco_warninglist['list']))
print(json.dumps(cisco_warninglist))



#!/usr/bin/env python3

from lxml import etree
from bs4 import BeautifulSoup
import datetime
import urllib.request, urllib.parse, urllib.error
import json

#webpage = urllib.request.urlopen("https://en.wikipedia.org/w/index.php?title=List_of_Google_domains&printable=yes")
webpage = urllib.request.urlopen("https://en.wikipedia.org/w/index.php?title=List_of_Google_domains")
soup = BeautifulSoup(webpage,'html.parser')

tables = soup.find_all("table", { "class" : "wikitable sortable" })
#print(tables)

gdomains = []
for tabl in tables :

    for row in tabl.findAll("tr"):
        cells = row.findAll('td')
        if len(cells) == 4:
            domain = cells[2].find_all(text=True)

            if len(domain) is 1 :
                domain = "{}".format(domain[0])
            elif len(domain) is 2 :
                domain = "{}{}".format(domain[0], domain[1])
            elif len(domain) is 3  and not "[" in domain[2]:
                domain = "{}{}".format(domain[0], domain[2])
            else:
                domain = "{}{}".format(domain[0], domain[1])

            print(domain)

            gdomains.append(domain)
#print(gdomains)
gdomains = sorted(set(gdomains))

google_warninglist = {}
version = int(datetime.date.today().strftime('%Y%m%d'))

google_warninglist['description'] = "Event contains one or more entries from the google owned domains."
d = datetime.datetime.now()
google_warninglist['version'] = version
google_warninglist['name'] = "Known Google domains"
google_warninglist['list'] = []
google_warninglist['matching_attributes'] = ['hostname', 'domain']

for site in gdomains:
    #v = str(site).split(',')[1]
    google_warninglist['list'].append(site)
google_warninglist['list'] = sorted(set(google_warninglist['list']))
#print(json.dumps(google_warninglist))                                                                       
